package com.goldenwater.slgc.service;

import java.util.List;
import com.goldenwater.slgc.domain.DocFile;

/** 文档文件 Service */
public interface DocFileService {
    /**
     * 查询文档文件列表
     *
     * @param docFile 查询条件
     * @return 文档文件列表
     */
    public List<DocFile> selectDocFileList(DocFile docFile);

    /**
     * 通过文件ID查询文档文件
     *
     * @param fileId 文件ID
     * @return 文档文件
     */
    public DocFile selectDocFileById(String fileId);

    /**
     * 删除文档文件
     *
     * @param fileIds 文件ID数组
     * @return 删除行数
     */
    public int deleteDocFileByIds(String[] fileIds);

    /**
     * 新增文档文件
     *
     * @param docFile 文档文件
     * @return 插入行数
     */
    public int insertDocFile(DocFile docFile);

    /**
     * 修改文档文件
     *
     * @param docFile 文档文件
     * @return 更新行数
     */
    public int updateDocFile(DocFile docFile);

    /**
     * 移动文档文件到指定分类
     *
     * @param fileIds 文件ID数组
     * @param fileCate 目标分类ID
     * @return 更新行数
     */
    public int moveDocFile(String[] fileIds, String fileCate);

    /**
     * 重命名文档文件
     *
     * @param fileId 文件ID
     * @param fileName 新文件名
     * @return 更新行数
     */
    public int renameDocFile(String fileId, String fileName);
}
